@@ -101,7 +101,17 @@ public:
     mir::frontend::BufferStreamId create_buffer_stream(mir::graphics::BufferProperties const& /*props*/) override { return {}; }
     std::shared_ptr<mir::frontend::BufferStream> get_buffer_stream(mir::frontend::BufferStreamId /*stream*/) const override { return nullptr; }
     void destroy_buffer_stream(mir::frontend::BufferStreamId /*stream*/) override {}
-
+    mir::graphics::BufferID create_buffer(mir::graphics::BufferProperties const&) override
+    {
+        return {};
+    }
+    void destroy_buffer(mir::graphics::BufferID) override
+    {
+    }
+    std::shared_ptr<mir::graphics::Buffer> get_buffer(mir::graphics::BufferID) override
+    {
+        return nullptr;
+    }
     std::string name() const override { return name_; }
     void send_display_config(mir::graphics::DisplayConfiguration const&) override {}
 
